#
# spec file for package nvme-stas
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nvme-stas
Version:        1.1.9
Release:        150400.3.9.3
Summary:        NVMe STorage Appliance Services
License:        Apache-2.0
URL:            https://github.com/linux-nvme/nvme-stas
Source0:        nvme-stas-%{version}.tar.gz
BuildRequires:  gobject-introspection
BuildRequires:  libnvme-devel >= 1.0~8
BuildRequires:  meson >= 0.52.0
BuildRequires:  python3
BuildRequires:  python3-dasbus
BuildRequires:  python3-gobject
BuildRequires:  python3-libnvme >= 1.0~8
BuildRequires:  python3-pyudev
BuildRequires:  python3-systemd
BuildRequires:  systemd-rpm-macros
Requires:       avahi
Requires:       python3-dasbus
Requires:       python3-gobject
Requires:       python3-libnvme >= 1.0~8
Requires:       python3-pyudev
Requires:       python3-systemd

%description
nvme-stas is a Central Discovery Controller (CDC) client for Linux. It
handles Asynchronous Event Notifications (AEN) handling, Automated,
NVMe subsystem connection controls, Error handling and reporting and
Automatic (zeroconf) and Manual configuration.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%define services stacd.service stafd.service

%pre
%service_add_pre %services

%post
%service_add_post %services

%preun
%service_del_preun %services

%postun
%service_del_postun %services

%files
%license LICENSE
%doc README.md
%dir %{_sysconfdir}/stas
%config(noreplace) %{_sysconfdir}/stas/stacd.conf
%config(noreplace) %{_sysconfdir}/stas/stafd.conf
%config(noreplace) %{_sysconfdir}/stas/sys.conf.doc
%{_datadir}/dbus-1/system.d/org.nvmexpress.stac.conf
%{_datadir}/dbus-1/system.d/org.nvmexpress.staf.conf
%{_bindir}/stacctl
%{_bindir}/stafctl
%{_bindir}/stasadm
%{_sbindir}/stacd
%{_sbindir}/stafd
%{_unitdir}/stacd.service
%{_unitdir}/stafd.service
%{python3_sitelib}/staslib
%{_unitdir}/stas*

%changelog
* Fri Mar 31 2023 mwilck@suse.com
- Update to version 1.1.9
  * Add _nvme-disc._udp to the list of mDNS service types
  * Fix RoCe and iwarp support (bsc#1207436)
* Tue Dec 13 2022 mwilck@suse.com
- Update to version 1.1.8:
  * Avahi: Handle upper/lower case 'NQN/nqn' in TXT attribute
    (bsc#1205873)
  * staslib: Trim whitespaces at the source (bsc#1204975)
  * stafd: Add "origin" parameter to DC controller objects
* Mon Aug  8 2022 mwilck@suse.com
- Update to version 1.1.6:
  Bug fix release
  * conf: Enable sticky-connections by default
  * staslib: check that async operation hasn't been cancelled before proceeding
  * stacd: fix I/O controller connection audits
  * staslib: add override support
  * systemd: add explicit dependency to modprobe@nvme_fabrics.service
* Mon Jul  4 2022 mwilck@suse.com
- Update to version 1.1.5 (bsc#1200128)
  Bug fix release
  * udev: fix I/O controller scan & detect algorithm
  * stacd: Fix D-Bus race condition between stacd and stafd.
  * staslib: fix support for fibre channel
  * doc: update README.md
  * staslib: fix race conditions during controller object removal.
  * stacd: fix defered call to remove_controller() with wrong arguments
  * staslib: make sure controller object gets "purged" when removed.
  * staslib: calling wrong cback function on controller removal.
  * staslib: Fix cback function deleting object that called the cback.
  * stacd: audit connections
  * stafd, stacd: Add man page to systend service file.
  * stacd: Add configuration parameter 'sticky-connections'
  * doc: troubleshoot guide for missing mDNS packets
  * stacd: allow disabling nvme-cli auto-connect udev rule.
- Added systemd service file (service disabled)
- Spec file: use %%python_sitelib rather than %%python_sitearch, and install
  everything under %%{python_sitelib}/staslib
* Wed Apr  6 2022 daniel.wagner@suse.com
- Update to version v1.0:
  * Do not call persistent_set() from libnvme
  * dbus: return native dbus data instead of json when possible.
  * update documentation
* Fri Mar 25 2022 daniel.wagner@suse.com
- Update to version 1.0-rc5:
  * Remove misconfiguration check. (bsc#1197361)
  * Document how to increase the number of interfaces that Avahi can monitor.
- Removed python3-netifaces dependency (bsc#1197361)
- Added ahahi dependency
- Do not list files twice (add %%dir to directory paths)
- Drop workaround for Python interpreter path fixup.
* Wed Mar 23 2022 daniel.wagner@suse.com
- Update to version 1.0-rc4:
  * Check ignore-iface when creating TransportId object
  * Adding man pages for ip-family and ignore-iface
  * Add ignore-iface and ip-family conf. options
  * Update the documentation
  * Change default address returned by name resolver
  * Filter out invalid IP addresses. (bsc#1197361)
  * When reading the Host NQN, warn people if the NQN seems invalid
  * Print descriptive message when unable to run stafctl/stacctl
  * Use the newly added cntlrtype to check the type of controller
  * minor fix to previous change to set the log level on libnvme
  * LOG: enable libnvme debug when trace is enabled
- Added python3-netifaces dependency
* Thu Mar  3 2022 daniel.wagner@suse.com
- Correct License information. This project is licenced under
  Apache License 2.0.
- Mark sys.conf.doc as config file.
* Thu Mar  3 2022 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: enable typelib
  introspection. This allows RPM to add a bunch of autodetected
  dependenices by inspecting the python scripts (basedon
  python-gobject).
* Wed Feb 23 2022 daniel.wagner@suse.com
- Update to version 1.0-rc2:
  * Fis github workflows to pull from upstream libnvme
  * TP8010 was merged into upstream libnvme. Some APIs have changed.
    This is to update nvme-stas to the new APIs.
  * A bunch of mostly cosmetic changes
  * Cleaning up a few things.
  * Simplifying mDNS configuration and updating documentation.
  * Changed DBus rules to only block setting properties
  * Restrict the Dbus "deny" rules to only the debug interface.
* Wed Feb 16 2022 daniel.wagner@suse.com
- Update to version 1.0-rc1:
  * fix comment
  * Perform explicit registration from user-space
  * Add known image to docker-compose
  * Add docker run/build way to README
  * Actions: Disable actions/setup-python
  * Actions: Work on incoming branch
  * Fixing docker compilation error
  * Update docker-publish.yml
  * Fix github workflow
  * removed unused code
  * D-Bus config fixes.
  * github workflow actions - fix PYTHONPATH
* Thu Jan 27 2022 daniel.wagner@suse.com
- Initial nvme-stas packaging
